var FullscreenAPI;
(function (FullscreenAPI) {
    FullscreenAPI["REQUESTFULLSCREEN"] = "requestFullscreen";
    FullscreenAPI["EXITFULLSCREEN"] = "exitFullscreen";
    FullscreenAPI["FULLSCREENELEMENT"] = "fullscreenElement";
    FullscreenAPI["FULLSCREENENABLED"] = "fullscreenEnabled";
    FullscreenAPI["FULLSCREENCHANGE"] = "fullscreenchange";
    FullscreenAPI["FULLSCREENERROR"] = "fullscreenerror";
})(FullscreenAPI || (FullscreenAPI = {}));
var HelperClass;
(function (HelperClass) {
    HelperClass["WEBKITFULLSCREEN"] = "theo-webkit-full-screen";
    HelperClass["WEBKITFULLSCREENANCESTOR"] = "theo-webkit-full-screen-ancestor";
})(HelperClass || (HelperClass = {}));
function polyfillTHEOplayerViewFullscreen() {
    var MAX_SIGNED_INT = Math.pow(2, 31) - 1;
    var theoFullscreenElement = null;
    function noOp() {
        return;
    }
    function elevateToTopOfStackingContexts(element) {
        element.classList.add(HelperClass.WEBKITFULLSCREEN);
        var parent = element.parentElement;
        while (parent) {
            parent.classList.add(HelperClass.WEBKITFULLSCREENANCESTOR);
            parent = parent.parentElement;
        }
    }
    function restoreOrderInStackingContexts(element) {
        element.classList.remove(HelperClass.WEBKITFULLSCREEN);
        var parent = element.parentElement;
        while (parent) {
            parent.classList.remove(HelperClass.WEBKITFULLSCREENANCESTOR);
            parent = parent.parentElement;
        }
    }
    Element.prototype[FullscreenAPI.REQUESTFULLSCREEN] = function () {
        var replacingOther = false;
        if (theoFullscreenElement) {
            replacingOther = true;
            theoFullscreenElement[FullscreenAPI.EXITFULLSCREEN](replacingOther).catch(noOp);
        }
        theoFullscreenElement = this;
        elevateToTopOfStackingContexts(this);
        if (!replacingOther) {
            theoplayerFullscreenHelper.enterFullScreenFromWeb();
        }
        this.dispatchEvent(new Event(FullscreenAPI.FULLSCREENCHANGE, { bubbles: true }));
        return Promise.resolve();
    };
    Element.prototype[FullscreenAPI.EXITFULLSCREEN] = function (replacingOther) {
        if (theoFullscreenElement !== this) {
            return Promise.reject(new TypeError('Element not fullscreen'));
        }
        theoFullscreenElement = null;
        restoreOrderInStackingContexts(this);
        if (!replacingOther) {
            theoplayerFullscreenHelper.exitFullScreenFromWeb();
        }
        this.dispatchEvent(new Event(FullscreenAPI.FULLSCREENCHANGE, { bubbles: true }));
        return Promise.resolve();
    };
    document[FullscreenAPI.EXITFULLSCREEN] = function () {
        if (theoFullscreenElement) {
            return theoFullscreenElement[FullscreenAPI.EXITFULLSCREEN]();
        }
        else {
            return Promise.reject(new TypeError('No fullscreen element'));
        }
    };
    Object.defineProperty(document, FullscreenAPI.FULLSCREENENABLED, {
        get: function () {
            return true;
        }
    });
    Object.defineProperty(document, FullscreenAPI.FULLSCREENELEMENT, {
        get: function () {
            return theoFullscreenElement;
        }
    });
    // screen.orientation.lock() would result in a rejected promise, so we just disable it to avoid console errors.
    ScreenOrientation.prototype.lock = ScreenOrientation.prototype.unlock = undefined; //TODO implement this natively
}
polyfillTHEOplayerViewFullscreen();
